@@ -257,7 +257,7 @@ $(function() {
 				cm.matchHighlight("CodeMirror-matchhighlight");
 
 				// Show editor statistics
-				showEditorStats(cm);
+				window.showEditorStats(cm);
 		});
 
 		// Hook up with change event
@@ -266,8 +266,10 @@ $(function() {
 				clearInterval(timeoutId);
 				timeoutId = setTimeout(function() {
 					var mode = cm.getOption("mode");
-					if(mode == "perl") {
+					if (mode == "perl") {
 						syntaxCheck(cm);
+					} else if (mode == "javascript") { 
+						$(document).trigger('action-jshint');
 					} else {
 						$("#pod").html('Only supported for Perl files');
 					}
@@ -310,7 +312,7 @@ $(function() {
 			editor.focus();
 
 			// Show editor stats at startup
-			showEditorStats(editor);
+			window.showEditorStats(editor);
 
 			// Trigger theme selection
 			$("#theme_selector").change();
@@ -319,6 +321,8 @@ $(function() {
 			if(mode == "perl") {
 				// Run syntax check at startup
 				syntaxCheck(editor);
+			} else if (mode == "javascript") { 
+				$(document).trigger('action-jshint');
 			} else {
 				$("#pod").html('Not supported for mode "' + mode + '"');
 			}
@@ -372,7 +376,7 @@ $(function() {
 		CodeMirror.autoLoadMode(cm, modeFile);	
 	}
 
-	var showEditorStats = function(cm) {
+	window.showEditorStats = function(cm) {
 
 		var cursor = cm.getCursor();
 		var selection = cm.getSelection();
@@ -459,6 +463,9 @@ $(function() {
 				}
 				syntaxCheckerWidgets.length = 0;
 
+				//TODO temporary solution until we can figure out how to cooperate
+				$(".farabi-error-icon").remove();
+
 				problemCount = problems.length;
 
 				var html = '';
@@ -469,6 +476,7 @@ $(function() {
 						"<th>Line</th>" +
 						"<th>Message</th>" +
 						"<th>File</th>" +
+						"<th>Source</th>" +
 						"</thead>";
 					html += "<tbody>";
 
@@ -490,15 +498,17 @@ $(function() {
 								{coverGutter: true, noHScroll: true}
 							)
 						);
-						
+
 						$(msg).click(function() {
 							$('a[href="#problems-tab"]').tab('show');
 						});
 
-						html += "<tr>" +
-							'<td class="problem-line">' + problem.line + "</td>" +
-							"<td>" + problem.message + "</td>" +
-							"<td>" + problem.file + "</td>" +
+						html += 
+							"<tr>" +
+								'<td class="problem-line">' + problem.line + "</td>" +
+								"<td>" + problem.message + "</td>" +
+								"<td>" + problem.file + "</td>" +
+								"<td>Syntax Check</td>" +
 							"</tr>";
 					}
 
@@ -517,7 +527,7 @@ $(function() {
 				});
 
 				// Update editor statistics
-				showEditorStats(editor);
+				window.showEditorStats(editor);
 			});
 
 		});
@@ -527,6 +537,112 @@ $(function() {
 		syntaxCheck(GetCurrentEditor());
 	});
 
+	// JSHint: JavaScript static code analysis
+	var jsHintWidgets = [];
+	var jsHint = function(editor) {
+		editor.operation(function(){
+			var i;
+			for (i = 0; i < jsHintWidgets.length; i++) {
+				editor.removeLineWidget(jsHintWidgets[i]);
+			}
+			jsHintWidgets.length = 0;
+
+			//TODO temporary solution until we can figure out how to cooperate
+			$(".farabi-error-icon").remove();
+
+			JSHINT(editor.getValue());
+			problemCount = JSHINT.errors.length;
+
+			var html = '';
+			if(JSHINT.errors.length > 0) {
+				
+				html += 
+					"<thead>" +
+						"<th>Line</th>" +
+						"<th>Message</th>" +
+						"<th>File</th>" +
+						"<th>Source</th>" +
+					"</thead>";
+				html += "<tbody>";
+				
+				for (var i = 0; i < JSHINT.errors.length; ++i) {
+					var problem = JSHINT.errors[i];
+					if (!problem) {
+						continue;
+					}
+
+					// Add warning or error under the editor line
+					var msg = document.createElement("div");
+					var icon = msg.appendChild(document.createElement("span"));
+					icon.innerHTML = "!!";
+					icon.className = "farabi-error-icon";
+					msg.appendChild(document.createTextNode(problem.reason));
+					msg.className = "farabi-error";
+
+					jsHintWidgets.push(
+						editor.addLineWidget(
+							problem.line - 1,
+							msg, 
+							{coverGutter: true, noHScroll: true}
+						)
+					);
+
+					$(msg).click(function() {
+						$('a[href="#problems-tab"]').tab('show');
+					});
+
+					html += 
+						"<tr>" +
+							'<td class="problem-line">' + problem.line + "</td>" +
+							"<td>" + problem.reason + "</td>" +
+							"<td></td>" +
+							"<td>JSHint</td>" +
+						"</tr>";
+				}
+
+				html += "</tbody>";
+			} else {
+				html = '<tr>' +
+					'<td><span class="badge badge-success">No problems found</span></td>' +
+						'</tr>';
+			}
+			
+			$("#problems > table").html(html);
+			$("#problems>  table > tbody > tr").click(function() { 
+				var line = parseInt($(".problem-line", this).text());
+				var editor = GetCurrentEditor();
+				editor.setCursor({line: line - 1, ch: 0});
+			});
+
+			// Update editor statistics
+			window.showEditorStats(editor);
+
+		});
+	};
+
+	$(document).on('action-jshint', function() {
+
+		// JSHint
+		var editor = GetCurrentEditor();
+		if("JSHint" in window) {
+
+			jsHint(editor);
+
+		} else {
+
+			// Load JSHint and then run
+			$.ajax({
+				url: 'assets/jshint/jshint.js',
+				dataType: "script",
+				success: function() {
+					jsHint(editor);
+				}
+			});
+
+		}
+
+	});
+
 	$(document).on('action-help', function() {
 		$helpDialog.modal("show");
 	});
